@@ -22,7 +22,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include <gnumeric-config.h>
-#include <gnumeric-i18n.h>
+#include <glib/gi18n.h>
 #include <gnumeric.h>
 #include <func.h>
 
@@ -31,6 +31,7 @@
 #include <str.h>
 #include <value.h>
 #include <mathfunc.h>
+#include <collect.h>
 
 #include <math.h>
 #include <limits.h>
@@ -47,14 +48,14 @@ GNUMERIC_MODULE_PLUGIN_INFO_DECL;
 /**
  * FIXME: In the long term this needs optimising.
  **/
-static Value *
-val_to_base (FunctionEvalInfo *ei, Value **argv, int num_argv,
+static GnmValue *
+val_to_base (FunctionEvalInfo *ei, GnmValue **argv, int num_argv,
 	     int src_base, int dest_base)
 {
-	Value *value;
+	GnmValue *value;
 	int max, places;
-	char *err, buffer[40];
-	const char *str;
+	char *err, buffer[80];
+	char const *str;
 	gnm_float v, b10;
 	int digit;
 
@@ -67,7 +68,7 @@ val_to_base (FunctionEvalInfo *ei, Value **argv, int num_argv,
 	if (VALUE_IS_EMPTY (value))
 		return value_new_error_NUM (ei->pos);
 	else if (VALUE_IS_EMPTY_OR_ERROR (value))
-		return value_duplicate (value);
+		return value_dup (value);
 
 	places = (num_argv >= 2 && argv[1]) ? value_get_as_int (argv[1]) : 0;
 	str = value_peek_string (value);
@@ -111,7 +112,7 @@ val_to_base (FunctionEvalInfo *ei, Value **argv, int num_argv,
 
 /***************************************************************************/
 
-static const char *help_bin2dec = {
+static char const *help_bin2dec = {
 	N_("@FUNCTION=BIN2DEC\n"
 	   "@SYNTAX=BIN2DEC(x)\n"
 
@@ -126,15 +127,15 @@ static const char *help_bin2dec = {
 	   "@SEEALSO=DEC2BIN, BIN2OCT, BIN2HEX")
 };
 
-static Value *
-gnumeric_bin2dec (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_bin2dec (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return val_to_base (ei, argv, 1, 2, 10);
 }
 
 /***************************************************************************/
 
-static const char *help_bin2oct = {
+static char const *help_bin2oct = {
 	N_("@FUNCTION=BIN2OCT\n"
 	   "@SYNTAX=BIN2OCT(number[,places])\n"
 
@@ -152,15 +153,15 @@ static const char *help_bin2oct = {
 	   "@SEEALSO=OCT2BIN, BIN2DEC, BIN2HEX")
 };
 
-static Value *
-gnumeric_bin2oct (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_bin2oct (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return val_to_base (ei, argv, 2, 2, 8);
 }
 
 /***************************************************************************/
 
-static const char *help_bin2hex = {
+static char const *help_bin2hex = {
 	N_("@FUNCTION=BIN2HEX\n"
 	   "@SYNTAX=BIN2HEX(number[,places])\n"
 
@@ -178,15 +179,15 @@ static const char *help_bin2hex = {
 	   "@SEEALSO=HEX2BIN, BIN2OCT, BIN2DEC")
 };
 
-static Value *
-gnumeric_bin2hex (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_bin2hex (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return val_to_base (ei, argv, 2, 2, 16);
 }
 
 /***************************************************************************/
 
-static const char *help_dec2bin = {
+static char const *help_dec2bin = {
 	N_("@FUNCTION=DEC2BIN\n"
 	   "@SYNTAX=DEC2BIN(number[,places])\n"
 
@@ -204,15 +205,15 @@ static const char *help_dec2bin = {
 	   "@SEEALSO=BIN2DEC, DEC2OCT, DEC2HEX")
 };
 
-static Value *
-gnumeric_dec2bin (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_dec2bin (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return val_to_base (ei, argv, 2, 10, 2);
 }
 
 /***************************************************************************/
 
-static const char *help_dec2oct = {
+static char const *help_dec2oct = {
 	N_("@FUNCTION=DEC2OCT\n"
 	   "@SYNTAX=DEC2OCT(number[,places])\n"
 
@@ -230,15 +231,15 @@ static const char *help_dec2oct = {
 	   "@SEEALSO=OCT2DEC, DEC2BIN, DEC2HEX")
 };
 
-static Value *
-gnumeric_dec2oct (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_dec2oct (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return val_to_base (ei, argv, 2, 10, 8);
 }
 
 /***************************************************************************/
 
-static const char *help_dec2hex = {
+static char const *help_dec2hex = {
 	N_("@FUNCTION=DEC2HEX\n"
 	   "@SYNTAX=DEC2HEX(number[,places])\n"
 
@@ -256,15 +257,15 @@ static const char *help_dec2hex = {
 	   "@SEEALSO=HEX2DEC, DEC2BIN, DEC2OCT")
 };
 
-static Value *
-gnumeric_dec2hex (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_dec2hex (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return val_to_base (ei, argv, 2, 10, 16);
 }
 
 /***************************************************************************/
 
-static const char *help_oct2dec = {
+static char const *help_oct2dec = {
 	N_("@FUNCTION=OCT2DEC\n"
 	   "@SYNTAX=OCT2DEC(x)\n"
 
@@ -279,15 +280,15 @@ static const char *help_oct2dec = {
 	   "@SEEALSO=DEC2OCT, OCT2BIN, OCT2HEX")
 };
 
-static Value *
-gnumeric_oct2dec (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_oct2dec (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return val_to_base (ei, argv, 1, 8, 10);
 }
 
 /***************************************************************************/
 
-static const char *help_oct2bin = {
+static char const *help_oct2bin = {
 	N_("@FUNCTION=OCT2BIN\n"
 	   "@SYNTAX=OCT2BIN(number[,places])\n"
 
@@ -305,15 +306,15 @@ static const char *help_oct2bin = {
 	   "@SEEALSO=BIN2OCT, OCT2DEC, OCT2HEX")
 };
 
-static Value *
-gnumeric_oct2bin (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_oct2bin (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return val_to_base (ei, argv, 2, 8, 2);
 }
 
 /***************************************************************************/
 
-static const char *help_oct2hex = {
+static char const *help_oct2hex = {
 	N_("@FUNCTION=OCT2HEX\n"
 	   "@SYNTAX=OCT2HEX(number[,places])\n"
 
@@ -331,15 +332,15 @@ static const char *help_oct2hex = {
 	   "@SEEALSO=HEX2OCT, OCT2BIN, OCT2DEC")
 };
 
-static Value *
-gnumeric_oct2hex (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_oct2hex (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return val_to_base (ei, argv, 2, 8, 16);
 }
 
 /***************************************************************************/
 
-static const char *help_hex2bin = {
+static char const *help_hex2bin = {
 	N_("@FUNCTION=HEX2BIN\n"
 	   "@SYNTAX=HEX2BIN(number[,places])\n"
 
@@ -357,15 +358,15 @@ static const char *help_hex2bin = {
 	   "@SEEALSO=BIN2HEX, HEX2OCT, HEX2DEC")
 };
 
-static Value *
-gnumeric_hex2bin (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_hex2bin (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return val_to_base (ei, argv, 2, 16, 2);
 }
 
 /***************************************************************************/
 
-static const char *help_hex2oct = {
+static char const *help_hex2oct = {
 	N_("@FUNCTION=HEX2OCT\n"
 	   "@SYNTAX=HEX2OCT(number[,places])\n"
 
@@ -383,15 +384,15 @@ static const char *help_hex2oct = {
 	   "@SEEALSO=OCT2HEX, HEX2BIN, HEX2DEC")
 };
 
-static Value *
-gnumeric_hex2oct (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_hex2oct (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return val_to_base (ei, argv, 2, 16, 8);
 }
 
 /***************************************************************************/
 
-static const char *help_hex2dec = {
+static char const *help_hex2dec = {
 	N_("@FUNCTION=HEX2DEC\n"
 	   "@SYNTAX=HEX2DEC(x)\n"
 
@@ -406,15 +407,15 @@ static const char *help_hex2dec = {
 	   "@SEEALSO=DEC2HEX, HEX2BIN, HEX2OCT")
 };
 
-static Value *
-gnumeric_hex2dec (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_hex2dec (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	return val_to_base (ei, argv, 1, 16, 10);
 }
 
 /***************************************************************************/
 
-static const char *help_besseli = {
+static char const *help_besseli = {
 	N_("@FUNCTION=BESSELI\n"
 	   "@SYNTAX=BESSELI(x,y)\n"
 
@@ -422,7 +423,7 @@ static const char *help_besseli = {
 	   "BESSELI function returns the Neumann, Weber or Bessel "
 	   "function.\n\n"
 	   "@x is where the function is evaluated. "
-	   "@y is the order of the bessel function, if non-integer it is "
+	   "@y is the order of the Bessel function, if non-integer it is "
 	   "truncated.\n"
 	   "\n"
 	   "* If @x or @y are not numeric a #VALUE! error is returned.\n"
@@ -436,8 +437,8 @@ static const char *help_besseli = {
 };
 
 
-static Value *
-gnumeric_besseli (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_besseli (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	gnm_float x, order;
 
@@ -452,7 +453,7 @@ gnumeric_besseli (FunctionEvalInfo *ei, Value **argv)
 
 /***************************************************************************/
 
-static const char *help_besselk = {
+static char const *help_besselk = {
 	N_("@FUNCTION=BESSELK\n"
 	   "@SYNTAX=BESSELK(x,y)\n"
 
@@ -460,11 +461,11 @@ static const char *help_besselk = {
 	   "BESSELK function returns the Neumann, Weber or Bessel "
 	   "function. "
 	   "@x is where the function is evaluated. "
-	   "@y is the order of the bessel function, if non-integer it is "
+	   "@y is the order of the Bessel function, if non-integer it is "
 	   "truncated.\n"
 	   "\n"
-	   "* If x or n are not numeric a #VALUE! error is returned.\n"
-	   "* If y < 0 a #NUM! error is returned.\n"
+	   "* If @x or @y are not numeric a #VALUE! error is returned.\n"
+	   "* If @y < 0 a #NUM! error is returned.\n"
 	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
@@ -473,8 +474,8 @@ static const char *help_besselk = {
 	   "@SEEALSO=BESSELI,BESSELJ,BESSELY")
 };
 
-static Value *
-gnumeric_besselk (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_besselk (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	gnm_float x, order;
 
@@ -489,14 +490,14 @@ gnumeric_besselk (FunctionEvalInfo *ei, Value **argv)
 
 /***************************************************************************/
 
-static const char *help_besselj = {
+static char const *help_besselj = {
 	N_("@FUNCTION=BESSELJ\n"
 	   "@SYNTAX=BESSELJ(x,y)\n"
 
 	   "@DESCRIPTION="
-	   "BESSELJ function returns the bessel function with "
+	   "BESSELJ function returns the Bessel function with "
 	   "@x is where the function is evaluated. "
-	   "@y is the order of the bessel function, if non-integer it is "
+	   "@y is the order of the Bessel function, if non-integer it is "
 	   "truncated.\n"
 	   "\n"
 	   "* If @x or @y are not numeric a #VALUE! error is returned.\n"
@@ -506,11 +507,11 @@ static const char *help_besselj = {
 	   "@EXAMPLES=\n"
 	   "BESSELJ(0.89,3) equals 0.013974004.\n"
 	   "\n"
-	   "@SEEALSO=BESSELJ,BESSELK,BESSELY")
+	   "@SEEALSO=BESSELI,BESSELK,BESSELY")
 };
 
-static Value *
-gnumeric_besselj (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_besselj (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	int x, y;
 
@@ -525,7 +526,7 @@ gnumeric_besselj (FunctionEvalInfo *ei, Value **argv)
 
 /***************************************************************************/
 
-static const char *help_bessely = {
+static char const *help_bessely = {
 	N_("@FUNCTION=BESSELY\n"
 	   "@SYNTAX=BESSELY(x,y)\n"
 
@@ -533,21 +534,21 @@ static const char *help_bessely = {
 	   "BESSELY function returns the Neumann, Weber or Bessel "
 	   "function.\n\n"
 	   "@x is where the function is evaluated. "
-	   "@y is the order of the bessel function, if non-integer it is "
+	   "@y is the order of the Bessel function, if non-integer it is "
 	   "truncated.\n"
 	   "\n"
-	   "* If x or n are not numeric a #VALUE! error is returned.\n"
-	   "* If n < 0 a #NUM! error is returned.\n"
+	   "* If @x or @y are not numeric a #VALUE! error is returned.\n"
+	   "* If @y < 0 a #NUM! error is returned.\n"
 	   "* This function is Excel compatible.\n"
 	   "\n"
 	   "@EXAMPLES=\n"
 	   "BESSELY(4,2) equals 0.215903595.\n"
 	   "\n"
-	   "@SEEALSO=BESSELJ,BESSELK,BESSELY")
+	   "@SEEALSO=BESSELI,BESSELJ,BESSELK")
 };
 
-static Value *
-gnumeric_bessely (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_bessely (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	int y;
 	if (argv[0]->type != VALUE_INTEGER &&
@@ -564,7 +565,11 @@ gnumeric_bessely (FunctionEvalInfo *ei, Value **argv)
 
 /***************************************************************************/
 
-static const char *help_convert = {
+/* FIXME: "deka" is US-centric. The official SI prefix is "deca" (see
+ * http://en.wikipedia.org/wiki/SI_unit and
+ * http://en.wikipedia.org/wiki/SI_prefix) */
+
+static char const *help_convert = {
 	N_("@FUNCTION=CONVERT\n"
 	   "@SYNTAX=CONVERT(number,from_unit,to_unit)\n"
 	   "@DESCRIPTION="
@@ -668,7 +673,7 @@ static const char *help_convert = {
 };
 
 typedef struct {
-        const char *str;
+        char const *str;
 	gnm_float c;
 } eng_convert_unit_t;
 
@@ -676,7 +681,7 @@ typedef struct {
 static gnm_float
 get_constant_of_unit(const eng_convert_unit_t units[],
 		     const eng_convert_unit_t prefixes[],
-		     const char *unit_name,
+		     char const *unit_name,
 		     gnm_float *c, gnm_float *prefix)
 {
         int i;
@@ -707,11 +712,11 @@ get_constant_of_unit(const eng_convert_unit_t units[],
 
 /* See also http://physics.nist.gov/cuu/Units/prefixes.html */
 
-static Value *
+static GnmValue *
 convert (const eng_convert_unit_t units[],
 	 const eng_convert_unit_t prefixes[],
-	 const char *from_unit, const char *to_unit,
-	 gnm_float n, Value **v, const EvalPos *ep)
+	 char const *from_unit, char const *to_unit,
+	 gnm_float n, GnmValue **v, const GnmEvalPos *ep)
 {
         gnm_float from_c, from_prefix, to_c, to_prefix;
 
@@ -733,8 +738,8 @@ convert (const eng_convert_unit_t units[],
 	return NULL;
 }
 
-static Value *
-gnumeric_convert (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_convert (FunctionEvalInfo *ei, GnmValue **argv)
 {
         /* Weight and mass constants */
         #define one_g_to_sg     0.00006852205001
@@ -921,8 +926,8 @@ gnumeric_convert (FunctionEvalInfo *ei, Value **argv)
 	};
 
 	gnm_float n;
-	const char *from_unit, *to_unit;
-	Value *v;
+	char const *from_unit, *to_unit;
+	GnmValue *v;
 
 	n = value_get_as_float (argv[0]);
 	from_unit = value_peek_string (argv[1]);
@@ -979,7 +984,7 @@ gnumeric_convert (FunctionEvalInfo *ei, Value **argv)
 
 /***************************************************************************/
 
-static const char *help_erf = {
+static char const *help_erf = {
 	N_("@FUNCTION=ERF\n"
 	   "@SYNTAX=ERF([lower limit,]upper_limit)\n"
 
@@ -1008,8 +1013,8 @@ static const char *help_erf = {
 };
 
 
-static Value *
-gnumeric_erf (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_erf (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	gnm_float ans, lower, upper;
 
@@ -1026,7 +1031,7 @@ gnumeric_erf (FunctionEvalInfo *ei, Value **argv)
 
 /***************************************************************************/
 
-static const char *help_erfc = {
+static char const *help_erfc = {
 	N_("@FUNCTION=ERFC\n"
 	   "@SYNTAX=ERFC(x)\n"
 
@@ -1044,8 +1049,8 @@ static const char *help_erfc = {
 	   "@SEEALSO=ERF")
 };
 
-static Value *
-gnumeric_erfc (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_erfc (FunctionEvalInfo *ei, GnmValue **argv)
 {
 	gnm_float x;
 
@@ -1056,14 +1061,14 @@ gnumeric_erfc (FunctionEvalInfo *ei, Value **argv)
 
 /***************************************************************************/
 
-static const char *help_delta = {
+static char const *help_delta = {
 	N_("@FUNCTION=DELTA\n"
 	   "@SYNTAX=DELTA(x[,y])\n"
 
 	   "@DESCRIPTION="
 	   "DELTA function tests for numerical equivalence of two "
 	   "arguments, returning 1 in case of equality.\n\n"
-	   "* @y is optional, and defaults to 0."
+	   "* @y is optional, and defaults to 0.\n"
 	   "* If either argument is non-numeric returns a #VALUE! error.\n"
 	   "* This function is Excel compatible.\n"
 	   "\n"
@@ -1074,12 +1079,12 @@ static const char *help_delta = {
 };
 
 
-static Value *
-gnumeric_delta (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_delta (FunctionEvalInfo *ei, GnmValue **argv)
 {
-	Value *err = NULL;
+	GnmValue *err = NULL;
 	gboolean ans = FALSE;
-	Value *vx, *vy;
+	GnmValue *vx, *vy;
 
 	vx = argv[0];
 	if (argv[1])
@@ -1111,7 +1116,7 @@ gnumeric_delta (FunctionEvalInfo *ei, Value **argv)
 
 /***************************************************************************/
 
-static const char *help_gestep = {
+static char const *help_gestep = {
 	N_("@FUNCTION=GESTEP\n"
 	   "@SYNTAX=GESTEP(x[,y])\n"
 	   "@DESCRIPTION="
@@ -1128,12 +1133,12 @@ static const char *help_gestep = {
 };
 
 
-static Value *
-gnumeric_gestep (FunctionEvalInfo *ei, Value **argv)
+static GnmValue *
+gnumeric_gestep (FunctionEvalInfo *ei, GnmValue **argv)
 {
-	Value *err = NULL;
+	GnmValue *err = NULL;
 	gboolean ans = FALSE;
-	Value *vx, *vy;
+	GnmValue *vx, *vy;
 
 	vx = argv[0];
 	if (argv[1])
@@ -1165,6 +1170,59 @@ gnumeric_gestep (FunctionEvalInfo *ei, Value **argv)
 
 /***************************************************************************/
 
+static char const *help_invsuminv = {
+	N_("@FUNCTION=INVSUMINV\n"
+	   "@SYNTAX=INVSUMINV(x1,x2,...)\n"
+	   "@DESCRIPTION="
+	   "INVSUMINV sum calculates the inverse of the sum of inverses.\n"
+	   "\n"
+	   "The primary use of this is for calculating equivalent resistance for "
+	   "parallel resistors or equivalent capacitance of a series of capacitors.\n"
+	   "\n"
+	   "* All arguments must be non-negative, or else a #VALUE! result is returned.\n"
+	   "* If any argument is zero, the result is zero.\n"
+	   "\n"
+	   "@EXAMPLES=\n"
+	   "INVSUMINV(2000,2000) equals 1000.\n"
+	   "\n"
+	   "@SEEALSO=HARMEAN")
+};
+
+static int
+range_invsuminv (gnm_float const *xs, int n, gnm_float *res)
+{
+	int i;
+	gnm_float suminv = 0;
+	gboolean zerop = FALSE;
+
+	if (n <= 0) return 1;
+
+	for (i = 0; i < n; i++) {
+		gnm_float x = xs[i];
+		if (x < 0) return 1;
+		if (x == 0)
+			zerop = TRUE;
+		else
+			suminv += 1 / x;
+	}
+
+	*res = zerop ? 0 : 1 / suminv;
+	return 0;
+}
+
+static GnmValue *
+gnumeric_invsuminv (FunctionEvalInfo *ei, GnmExprList *nodes)
+{
+	return float_range_function (nodes, ei,
+				     range_invsuminv,
+				     COLLECT_IGNORE_STRINGS |
+				     COLLECT_IGNORE_BOOLS |
+				     COLLECT_IGNORE_BLANKS,
+				     GNM_ERROR_VALUE);
+}
+
+/***************************************************************************/
+
 const GnmFuncDescriptor engineering_functions[] = {
         { "besseli",     "ff",   "xnum,ynum", &help_besseli,
 	  gnumeric_besseli, NULL, NULL, NULL, NULL,
@@ -1226,6 +1284,10 @@ const GnmFuncDescriptor engineering_functions[] = {
 	  gnumeric_hex2oct, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 
+	{ "invsuminv",    NULL, "",           &help_invsuminv,
+	  NULL, gnumeric_invsuminv, NULL, NULL, NULL,
+	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
+
         { "oct2bin",     "S|f",  "xnum,ynum", &help_oct2bin,
 	  gnumeric_oct2bin, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
