@@ -53,6 +53,7 @@
 #include <print-info.h>
 #include <xml-io.h>
 #include <tools/scenarios.h>
+#include <gnumeric-gconf.h>
 
 #include <gsf/gsf-libxml.h>
 #include <gsf/gsf-output-gzip.h>
@@ -106,6 +107,17 @@ xml_write_attribute (GnmOutputXML *state, char const *name, char const *value)
 	gsf_xml_out_end_element (state->output); /* </Attribute> */
 }
 
+static void
+xml_write_version (GnmOutputXML *state)
+{
+	gsf_xml_out_start_element (state->output, GMR "Version");
+	gsf_xml_out_add_int (state->output, "Epoch", GNM_VERSION_EPOCH);
+	gsf_xml_out_add_int (state->output, "Major", GNM_VERSION_MAJOR);
+	gsf_xml_out_add_int (state->output, "Minor", GNM_VERSION_MINOR);
+	gsf_xml_out_add_cstr_unchecked (state->output, "Full", GNUMERIC_VERSION);
+	gsf_xml_out_end_element (state->output); /* </Version> */
+}
+
 static void
 xml_write_attributes (GnmOutputXML *state)
 {
@@ -265,7 +277,7 @@ xml_write_print_hf (GnmOutputXML *state, char const *name,
 static void
 xml_write_print_info (GnmOutputXML *state, PrintInformation *pi)
 {
-	guchar *paper_name;
+	char const *paper_name;
 	double header = 0, footer = 0, left = 0, right = 0;
 
 	g_return_if_fail (pi != NULL);
@@ -332,12 +344,9 @@ xml_write_print_info (GnmOutputXML *state, PrintInformation *pi)
 	xml_write_print_hf (state, GMR "Header", pi->header);
 	xml_write_print_hf (state, GMR "Footer", pi->footer);
 
-	paper_name = gnome_print_config_get (pi->print_config,
-					     (guchar *)GNOME_PRINT_KEY_PAPER_SIZE);
-	if (paper_name) {
+	paper_name = print_info_get_paper (pi);
+	if (paper_name)
 		gsf_xml_out_simple_element (state->output, GMR "paper", paper_name);
-		g_free (paper_name);
-	}
 
 	gsf_xml_out_end_element (state->output);
 }
@@ -468,6 +477,7 @@ xml_write_gnmstyle (GnmOutputXML *state, GnmStyle const *style)
 			gsf_xml_out_simple_element (state->output, GMR "Expression1", tmp);
 			g_free (tmp);
 		}
+		gsf_xml_out_end_element (state->output); /* </Validation> */
 	}
 
 	i = MSTYLE_BORDER_TOP;
@@ -1135,7 +1145,9 @@ xml_sax_file_save (GnmFileSaver const *fs, IOContext *io_context,
 	GsfOutput *gzout = NULL;
 
 	/* If the suffix is .xml disable compression */
-	if (extension == NULL || g_ascii_strcasecmp (extension, "xml") != 0) {
+	if (extension == NULL ||
+	    g_ascii_strcasecmp (extension, "xml") != 0 ||
+	    gnm_app_prefs->xml_compression_level != 0) {
 		gzout  = gsf_output_gzip_new (output, NULL);
 		output = gzout;
 	}
@@ -1162,6 +1174,7 @@ xml_sax_file_save (GnmFileSaver const *fs, IOContext *io_context,
 	gsf_xml_out_add_cstr_unchecked (state.output, "xsi:schemaLocation",
 		"http://www.gnumeric.org/v8.xsd");
 
+	xml_write_version	    (&state);
 	xml_write_attributes	    (&state);
 	xml_write_summary	    (&state);
 	xml_write_conventions	    (&state);
