@@ -340,11 +340,17 @@ gog_plot_foreach_elem (GogPlot *plot, gboolean only_visible,
 	unsigned i, n, num_labels = 0;
 	char *label = NULL;
 	GogTheme *theme = gog_object_get_theme (GOG_OBJECT (plot));
+	GogPlotClass *klass = GOG_PLOT_GET_CLASS (plot);
 	GList *overrides;
 
 	g_return_if_fail (GOG_PLOT (plot) != NULL);
 	g_return_if_fail (plot->cardinality_valid);
 
+	if (klass->foreach_elem) {
+		klass->foreach_elem (plot, only_visible, func, data);
+		return;
+	}
+
 	ptr = plot->series;
 	if (ptr == NULL)
 		return;
@@ -432,6 +438,7 @@ gog_plot_get_axis_bounds (GogPlot *plot, GogAxisType axis,
 	bounds->logical.maxima = go_nan;
 	bounds->logical.minima = go_nan;
 	bounds->is_discrete = FALSE;
+	bounds->center_on_ticks = FALSE;
 	if (klass->axis_get_bounds == NULL)
 		return NULL;
 	return (klass->axis_get_bounds) (plot, axis, bounds);
