@@ -190,6 +190,7 @@ gui_file_open (WorkbookControlGUI *wbcg, char const *default_format)
 	char *uri = NULL;
 	const char *encoding = NULL;
 	GnmFileOpener *fo = NULL;
+	Workbook *workbook = wb_control_workbook (WORKBOOK_CONTROL (wbcg));
 
 	openers = g_list_sort (g_list_copy (get_file_openers ()),
 			       file_opener_description_cmp);
@@ -228,6 +229,17 @@ gui_file_open (WorkbookControlGUI *wbcg, char const *default_format)
 				NULL);
 	gtk_dialog_set_default_response (GTK_DIALOG (fsel), GTK_RESPONSE_OK);
 
+	/* Add Templates bookmark */
+	{
+		char *templates = gnm_sys_data_dir ("templates");
+		gtk_file_chooser_add_shortcut_folder (fsel, templates, NULL);
+		g_free (templates);
+	}
+
+	/* Start in the same directory as the current workbook.  */
+	gtk_file_chooser_select_uri (fsel, workbook_get_uri (workbook));
+	gtk_file_chooser_unselect_all (fsel);
+
 	/* Filters */
 	{	
 		GtkFileFilter *filter;
@@ -241,28 +253,17 @@ gui_file_open (WorkbookControlGUI *wbcg, char const *default_format)
 		filter = gtk_file_filter_new ();
 		gtk_file_filter_set_name (filter, _("Spreadsheets"));
 		for (l = openers->next; l; l = l->next) {
-			GnmFileOpener *o = l->data;
-			/* FIXME: add all known extensions.  */
-		}
-#warning "FIXME: make extension discovery above work and delete these"
-		/* Use _SAVERS'_ extension for lack of better.  */
-		for (l = get_file_savers ()->next; l; l = l->next) {
-			GnmFileSaver *fs = l->data;
-			const char *ext = gnm_file_saver_get_extension (fs);
-			const char *mime = gnm_file_saver_get_mime_type (fs);
-
-			if (mime)
-				gtk_file_filter_add_mime_type (filter, mime);
-
-			if (ext) {
-				char *pattern = g_strconcat ("*.", ext, NULL);
+			GnmFileOpener const *o = l->data;
+			GSList const *ptr;
+			for (ptr = gnm_file_opener_get_suffixes	(o); ptr != NULL ; ptr = ptr->next) {
+				char *pattern = g_strconcat ("*.", ptr->data, NULL);
 				gtk_file_filter_add_pattern (filter, pattern);
 				g_free (pattern);
 			}
+			for (ptr = gnm_file_opener_get_mimes	(o); ptr != NULL ; ptr = ptr->next)
+				gtk_file_filter_add_mime_type (filter, ptr->data);
+
 		}
-		/* FIXME: delete these also when we can ask the openers.  */
-		gtk_file_filter_add_pattern (filter, "*.csv");
-		gtk_file_filter_add_pattern (filter, "*.tsv");
 
 		gtk_file_chooser_add_filter (fsel, filter);
 		/* Make this filter the default */
@@ -386,7 +387,11 @@ go_file_is_writable (char const *uri, GtkWindow *parent)
 	if (!filename)
 		return TRUE;  /* Just assume writable.  */
 
-	if (filename [strlen (filename) - 1] == G_DIR_SEPARATOR ||
+#ifndef G_IS_DIR_SEPARATOR
+/* Recent glib 2.6 addition.  */
+#define G_IS_DIR_SEPARATOR(c) ((c) == G_DIR_SEPARATOR || (c) == '/')
+#endif
+	if (G_IS_DIR_SEPARATOR (filename [strlen (filename) - 1]) ||
 	    g_file_test (filename, G_FILE_TEST_IS_DIR)) {
 		char *msg = g_strdup_printf (_("%s\nis a directory name"), uri);
 		gnumeric_notice (parent, GTK_MESSAGE_ERROR, msg);
@@ -400,7 +405,7 @@ go_file_is_writable (char const *uri, GtkWindow *parent)
 		g_free (msg);
 		result = FALSE;
 	} else if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
-		char *dirname = g_path_get_dirname (uri);
+		char *dirname = go_dirname_from_uri (uri, TRUE);
 		char *basename = go_basename_from_uri (uri);
 		char *msg = g_markup_printf_escaped (
 			_("A file called <i>%s</i> already exists in %s.\n\n"
