@@ -18,20 +18,31 @@ SheetControlGUI *sheet_control_gui_new	    (SheetView *sv, WorkbookControlGUI *w
 GtkWidget *scg_toplevel		(SheetControlGUI *scg);
 void scg_take_focus             (SheetControlGUI *scg);
 
-void scg_mode_edit_object	(SheetControlGUI *scg, SheetObject *so);
 void scg_mode_create_object	(SheetControlGUI *scg, SheetObject *so);
 
 void scg_context_menu		(SheetControlGUI *scg, GdkEventButton *event,
 				 gboolean is_col, gboolean is_row);
-void scg_object_nudge		(SheetControlGUI *scg, int x_offset, int y_offset);
-void scg_object_update_bbox	(SheetControlGUI *scg, SheetObject *so, double const *offset);
-void scg_object_calc_position	(SheetControlGUI *scg, SheetObject *so, double const *coords);
-void scg_object_view_position	(SheetControlGUI *scg, SheetObject *so, double *coords);
-void scg_object_stop_editing	(SheetControlGUI *scg, SheetObject *so);
 
-void scg_comment_select		(SheetControlGUI *scg, CellComment *cc);
-void scg_comment_display	(SheetControlGUI *scg, CellComment *cc);
-void scg_comment_unselect	(SheetControlGUI *scg, CellComment *cc);
+void scg_object_anchor_to_coords (SheetControlGUI const *scg,
+				  SheetObjectAnchor const *anchor, double *coords);
+void scg_object_coords_to_anchor (SheetControlGUI const *scg,
+				  double const *coords, SheetObjectAnchor *in_out);
+
+void scg_objects_drag		(SheetControlGUI *scg, SheetObject *primary,
+				 gdouble dx, gdouble dy,
+				 int drag_type, gboolean symmetric);
+void scg_objects_drag_commit	(SheetControlGUI *scg, int drag_type,
+				 gboolean created_objects);
+void scg_objects_nudge		(SheetControlGUI *scg,
+				 int drag_type, int dx, int dy,
+				 gboolean symmetric);
+
+void scg_object_select		(SheetControlGUI *scg, SheetObject *so);
+void scg_object_unselect	(SheetControlGUI *scg, SheetObject *so);
+
+void scg_comment_select		(SheetControlGUI *scg, GnmComment *cc);
+void scg_comment_display	(SheetControlGUI *scg, GnmComment *cc);
+void scg_comment_unselect	(SheetControlGUI *scg, GnmComment *cc);
 
 void scg_select_all		(SheetControlGUI *scg);
 gboolean scg_colrow_select	(SheetControlGUI *scg,
@@ -90,8 +101,8 @@ GnmCanvas	   *scg_pane		(SheetControlGUI *scg, int pane);
 WorkbookControlGUI *scg_get_wbcg	(SheetControlGUI const *scg);
 
 /* FIXME : Move this around to a more reasonable location */
-StyleFont * scg_get_style_font (PangoContext *context,
+GnmFont * scg_get_style_font (PangoContext *context,
 				Sheet const *sheet,
-				MStyle const *style);
+				GnmStyle const *style);
 
 #endif /* GNUMERIC_SHEET_CONTROL_GUI_H */
